<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...

	<?php if ( get_header_image() ) : ?>
	<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
		<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="">
	</a>
	<?php endif; // End header image check. ?>

 *
 * @package Magzimum
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses magzimum_header_style()
 * @uses magzimum_admin_header_style()
 * @uses magzimum_admin_header_image()
 */
function magzimum_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'magzimum_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => '000000',
		'width'                  => 1600,
		'height'                 => 400,
		'flex-height'            => true,
		'admin-preview-callback' => 'magzimum_admin_header_image',
	) ) );
}
add_action( 'after_setup_theme', 'magzimum_custom_header_setup' );

if ( ! function_exists( 'magzimum_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see magzimum_custom_header_setup().
 */
function magzimum_admin_header_image() {
	$style = sprintf( ' style="color:#%s;"', get_header_textcolor() );
?>
	<div id="headimg">
		<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div class="displaying-header-text" id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php if ( get_header_image() ) : ?>
		<img src="<?php header_image(); ?>" alt="">
		<?php endif; ?>
	</div>
<?php
}
endif; // magzimum_admin_header_image


if ( ! function_exists( 'magzimum_featured_image' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own magzimum_featured_image(), and that function will be used instead.
	 *
	 * @since Magzimum 1.0
	 */
	function magzimum_featured_image() {
		$header_image 			= get_header_image();
		
		$options['featured_header_image_url'] = magzimum_get_option( 'featured_header_image_url' );
		
		$options['featured_header_image_base'] = magzimum_get_option( 'featured_header_image_base' );
		
		$options['featured_header_image_alt'] = magzimum_get_option( 'featured_header_image_alt' );

		$options['featured_header_image_url'] = magzimum_get_option( 'featured_header_image_url' );

		$magzimum_featured_image = '';

		if ( $header_image != '' ) {				
			// Header Image Link and Target
			if ( !empty( $options[ 'featured_header_image_url' ] ) ) {
				//support for qtranslate custom link
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$link = qtrans_convertURL( $options[ 'featured_header_image_url' ] );
				}
				else {
					$link = esc_url( $options[ 'featured_header_image_url' ] );
				}
				//Checking Link Target
				if ( !empty( $options[ 'featured_header_image_base' ] ) )  {
					$target = '_blank'; 	
				}
				else {
					$target = '_self'; 	
				}
			}
			else {
				$link = '';
				$target = '';
			}
			
			// Header Image Title/Alt
			if ( !empty( $options[ 'featured_header_image_alt' ] ) ) {
				$title = esc_attr( $options[ 'featured_header_image_alt' ] ); 	
			}
			else {
				$title = '';
			}
			
			// Header Image
			$feat_image = '<img class="wp-post-image" alt="'.$title.'" src="'.esc_url(  $header_image ).'" />';
			
			$magzimum_featured_image = '<div id="header-featured-image" class="site-header-image">
				<div class="container">';
				// Header Image Link 
				if ( !empty( $options[ 'featured_header_image_url' ] ) ) :
					$magzimum_featured_image .= '<a title="'. esc_attr( $title ).'" href="'. esc_url( $link ) .'" target="'.$target.'">' . $feat_image . '</a>'; 	
				else:
					// if empty featured_header_image on theme options, display default
					$magzimum_featured_image .= $feat_image;
				endif;
			$magzimum_featured_image .= '</div><!-- .container -->
			</div><!-- #header-featured-image -->';
		}
		
		echo $magzimum_featured_image;
		
	} // magzimum_featured_image
endif;


if ( ! function_exists( 'magzimum_featured_page_post_image' ) ) :
	/**
	 * Template for Featured Header Image from Post and Page
	 *
	 * To override this in a child theme
	 * simply create your own magzimum_featured_imaage_pagepost(), and that function will be used instead.
	 *
	 * @since Magzimum 1.0
	 */
	function magzimum_featured_page_post_image() {
		global $post, $wp_query;

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();
		$page_for_posts = get_option('page_for_posts');

		if ( is_home() && $page_for_posts == $page_id ) {
			$header_page_id = $page_id;
		}
		else {
			$header_page_id = $post->ID;
		}

		if( has_post_thumbnail( $header_page_id ) ) {
		   	
			$featured_header_image_url	= magzimum_get_option( 'featured_header_image_url' );
			
			$featured_header_image_base	= magzimum_get_option( 'featured_header_image_base' );

			if ( '' != $featured_header_image_url ) {
				//support for qtranslate custom link
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$link = qtrans_convertURL( $featured_header_image_url );
				}
				else {
					$link = esc_url( $featured_header_image_url );
				}
				//Checking Link Target
				if ( $featured_header_image_base ) {
					$target = '_blank';
				}
				else {
					$target = '_self'; 	
				}
			}
			else {
				$link = '';
				$target = '';
			}
			
			$featured_header_image_alt	= magzimum_get_option( 'featured_header_image_alt' );

			// Header Image Title/Alt
			if ( '' != $featured_header_image_alt ) {
				$title = esc_attr( $featured_header_image_alt ); 	
			}
			else {
				$title = '';
			}
			
			$featured_image_size = magzimum_get_option( 'featured_image_size' );
			
			$feat_image = get_the_post_thumbnail( $header_page_id, $featured_image_size, array('id' => 'main-feat-img'));
			
			$magzimum_featured_image = '<div id="header-featured-image" class =' . $featured_image_size . '>';
				// Header Image Link 
				if ( '' != $featured_header_image_url ) :
					$magzimum_featured_image .= '<a title="'. esc_attr( $title ).'" href="'. esc_url( $link ) .'" target="'.$target.'">' . $feat_image . '</a>'; 	
				else:
					// if empty featured_header_image on theme options, display default
					$magzimum_featured_image .= $feat_image;
				endif;
			$magzimum_featured_image .= '</div><!-- #header-featured-image -->';
			
			echo $magzimum_featured_image;
		}
		else {
			magzimum_featured_image();
		}		
	} // magzimum_featured_page_post_image
endif;


if ( ! function_exists( 'magzimum_featured_overall_image' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own magzimum_featured_pagepost_image(), and that function will be used instead.
	 *
	 * @since Magzimum 1.0
	 */
	function magzimum_featured_overall_image() {
		global $post, $wp_query;
		$enableheaderimage = magzimum_get_option( 'enable_featured_header_image' );
		
		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();

		$page_for_posts = get_option('page_for_posts');

		// Check Enable/Disable header image in Page/Post Meta box
		if ( is_page() || is_single() ) {
			//Individual Page/Post Image Setting
			$individual_featured_image = get_post_meta( $post->ID, 'magzimum-header-image', true ); 

			if ( $individual_featured_image == 'disable' || ( $individual_featured_image == 'default' && $enableheaderimage == 'disable' ) ) {
				echo '<!-- Page/Post Disable Header Image -->';
				return;
			}
			elseif ( $individual_featured_image == 'enable' && $enableheaderimage == 'disabled' ) {
				magzimum_featured_page_post_image();
			}
		}

		// Check Homepage 
		if ( $enableheaderimage == 'homepage' ) {
			if ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) {
				magzimum_featured_image();
			}
		}
		// Check Excluding Homepage 
		if ( $enableheaderimage == 'exclude-home' ) {
			if ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) {
				return false;
			}
			else {
				magzimum_featured_image();	
			}
		}
		elseif ( $enableheaderimage == 'exclude-home-page-post' ) {
			if ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) {
				return false;
			}
			elseif ( is_page() || is_single() ) {
				magzimum_featured_page_post_image();
			}
			else {
				magzimum_featured_image();
			}
		}
		// Check Entire Site
		elseif ( $enableheaderimage == 'entire-site' ) {
			magzimum_featured_image();
		}
		// Check Entire Site (Post/Page)
		elseif ( $enableheaderimage == 'entire-site-page-post' ) {
			if ( is_page() || is_single() || ( is_home() && $page_for_posts == $page_id ) ) {
				magzimum_featured_page_post_image();
			}
			else {
				magzimum_featured_image();
			}
		}	
		// Check Page/Post
		elseif ( $enableheaderimage == 'pages-posts' ) {
			if ( is_page() || is_single() ) {
				magzimum_featured_page_post_image();
			}
		}
		else {
			echo '<!-- Disable Header Image -->';
		}
	} // magzimum_featured_overall_image
endif;

add_action( 'magzimum_action_after_header', 'magzimum_featured_overall_image', 20 );