<?php

add_filter( 'magzimum_filter_default_theme_options', 'magzimum_featured_content_default_options' );

/**
 * Featured content defaults.
 *
 * @since  Magzimum 1.0
 */
if( ! function_exists( 'magzimum_featured_content_default_options' ) ):

  function magzimum_featured_content_default_options( $input ){

    $input['featured_content_status']           = 'home-page-only';
    $input['featured_content_show_arrow']       = true;
    $input['featured_content_show_blog']        = false;
    $input['featured_content_show_thumbnail']   = true;
    $input['featured_content_show_date']        = true;
    $input['featured_content_show_category']    = false;
    $input['featured_content_enable_autoplay']  = false;
    $input['featured_content_transition_delay'] = 3;
    $input['featured_content_type']             = 'featured-category';
    $input['featured_content_number']           = 6;
    $input['featured_content_category']         = array();

    return $input;
  }

endif;



add_filter( 'magzimum_theme_options_args', 'magzimum_featured_content_theme_options_args' );


/**
 * Add featured content options.
 *
 * @since  Magzimum 1.0
 */

if( ! function_exists( 'magzimum_featured_content_theme_options_args' ) ):

  function magzimum_featured_content_theme_options_args( $args ){

    // Create featured content option panel
    $args['panels']['featured_content_panel']['title'] = esc_html__( 'Featured Content', 'magzimum' );

    // Settings Section
    $args['panels']['featured_content_panel']['sections']['section_content_settings'] = array(
      'title'    => esc_html__( 'Content Settings', 'magzimum' ),
      'priority' => 65,
      'fields'   => array(

        'featured_content_show_arrow' => array(
          'title'             => esc_html__( 'Show Arrow', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_content_show_thumbnail' => array(
          'title'             => esc_html__( 'Show Thumbnail', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_content_show_blog' => array(
          'title'             => esc_html__( 'Remove featured posts from blog', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_content_show_date' => array(
          'title'             => esc_html__( 'Show Date', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_content_show_category' => array(
          'title'             => esc_html__( 'Show Category', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_content_enable_autoplay' => array(
          'title'             => esc_html__( 'Enable Autoplay', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_content_transition_delay' => array(
          'title'             => esc_html__( 'Transition Delay', 'magzimum' ),
          'description'       => esc_html__( 'In second(s)', 'magzimum' ),
          'type'              => 'number',
          'sanitize_callback' => 'absint',
          'input_attrs'       => array(
                                'min'   => 1,
                                'max'   => 10,
                                'step'  => 1,
                                'style' => 'width: 50px;'
                                ),

        ),


      )
    );

    // Icons Section
    $args['panels']['featured_content_panel']['sections']['section_content_type'] = array(
      'title'    => esc_html__( 'Content Type', 'magzimum' ),
      'priority' => 50,
      'fields'   => array(
        'featured_content_status' => array(
          'title'   => esc_html__( 'Enable Featured Content on', 'magzimum' ),
          'type'    => 'select',
          'choices' => magzimum_get_featured_status_options(),
          'priority'=>  1,
        ),
        'featured_content_type' => array(
          'title'             => esc_html__( 'Select Content Type', 'magzimum' ),
          'type'              => 'select',
          'choices'           => magzimum_get_featured_content_type_options(),
          'sanitize_callback' => 'sanitize_key',
          'priority'          =>  2,
        ),
        'featured_content_number' => array(
          'title'             => esc_html__( 'No of Posts', 'magzimum' ),
          'type'              => 'number',
          'sanitize_callback' => 'absint',
          'input_attrs'       => array(
                                  'min'   => 1,
                                  'max'   => 20,
                                  'style' => 'width: 55px;'
                                ),
          'priority'          =>  3,
        ),
      )
    );

    return $args;
  }

endif;


add_action( 'customize_register', 'magzimum_featured_content_loop_options' );

/**
 * Add featured content post, page and image loop
 *
 * @since  Magzimum 1.0
 */

if( ! function_exists( 'magzimum_featured_content_loop_options' ) ):

  function magzimum_featured_content_loop_options( $wp_customize ){
    $wp_customize->add_setting( 'theme_options[featured_content_category]', array(
          'capability'        => 'edit_theme_options',
          'sanitize_callback' => 'magzimum_sanitize_category_list',
        ) 
      );

    $wp_customize->add_control( new Magzimum_Customize_Dropdown_Multiple_Taxonomies_Control( $wp_customize, 'theme_options[featured_content_category]', array(
        'name'              => 'theme_options[featured_content_category]',
        'label'             => esc_html__( 'Select Categories', 'magzimum' ),
        'priority'          =>  7,
        'section'           => 'section_content_type',
        'settings'          => 'theme_options[featured_content_category]',
        'type'              => 'multiple-categories',
        'active_callback'   => 'magzimum_is_featured_category_content_active'
    ) ) );

    $featured_content_number   = magzimum_get_option( 'featured_content_number' );

    for ( $i=1; $i <=  $featured_content_number ; $i++ ) {
      //Featured Post
      $wp_customize->add_setting( 'theme_options[featured_content_post_'. $i .']', array(
          'capability'        => 'edit_theme_options',
          'sanitize_callback' => 'absint', 
        ) 
      );

      $wp_customize->add_control( 'theme_options[featured_content_post_'. $i .']', array(
        'input_attrs'         => array(
            'style' => 'width: 40px;'
          ),
        'label'             => esc_html__( 'Featured Post ID', 'magzimum' ) . ' ' . $i ,
        'priority'          =>  '4' . $i,
        'section'           => 'section_content_type',
        'settings'          => 'theme_options[featured_content_post_'. $i .']',
        'type'              => 'text',
        'active_callback'   => 'magzimum_is_featured_post_content_active'
        )
      );

      //Featured Page
      $wp_customize->add_setting( 'theme_options[featured_content_page_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'absint',
        ) 
      );

      $wp_customize->add_control( 'theme_options[featured_content_page_'. $i .']', array(
        'label'     => esc_html__( 'Featured Page', 'magzimum' ) . ' ' . $i ,
        'priority'  => '5' . $i,
        'section'   => 'section_content_type',
        'settings'  => 'theme_options[featured_content_page_'. $i .']',
        'type'      => 'dropdown-pages',
        'active_callback'   => 'magzimum_is_featured_page_content_active'
        ) 
      );
    
      //Featured Image
      $wp_customize->add_setting( 'theme_options[featured_content_note_'. $i .']', array(
        'capability'    => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
      ) );

      $wp_customize->add_control( new Magzimum_Customize_Heading_Control( $wp_customize, 'theme_options[featured_content_note_'. $i .']', array(
            'label'     => esc_html__( 'Featured Content #', 'magzimum' ) .  $i,
            'priority'  => '6' . $i,
            'section'   => 'section_content_type',
            'settings'  => 'theme_options[featured_content_note_'. $i .']',
            'type'      => 'heading',
            'active_callback'   => 'magzimum_is_featured_image_content_active'
        ) ) );

      $wp_customize->add_setting( 'theme_options[featured_content_title_'. $i .']', array(
        'capability'    => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
      ) );

      $wp_customize->add_control( 'theme_options[featured_content_title_'. $i .']', array(
        'label'     => esc_html__( 'Title', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_content_type',
        'settings'  => 'theme_options[featured_content_title_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_content_active',
        'type'      => 'text',
        ) );

      $wp_customize->add_setting( 'theme_options[featured_content_image_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
      ) );

      $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'theme_options[featured_content_image_'. $i .']', array(
        'label'     => esc_html__( 'Image', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_content_type',
        'settings'  => 'theme_options[featured_content_image_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_content_active'
      ) ) );

      $wp_customize->add_setting( 'theme_options[featured_content_link_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
      ) );

      $wp_customize->add_control(  'theme_options[featured_content_link_'. $i .']', array(
        'label'     => esc_html__( 'Link', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_content_type',
        'settings'  => 'theme_options[featured_content_link_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_content_active',
      ) );

      $wp_customize->add_setting( 'theme_options[featured_content_target_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_key',
      ) );

      $wp_customize->add_control(  'theme_options[featured_content_target_'. $i .']', array(
        'label'     => esc_html__( 'Check to Open Link in New Window/Tab', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_content_type',
        'settings'  => 'theme_options[featured_content_target_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_content_active',
        'type'      => 'checkbox',
      ) );
    }
  }

endif;


/**
 * Sanitizes category list in slider
 * @param  $input entered value
 * @return sanitized output
 *
 * @since Magzimum 1.0
 */
function magzimum_sanitize_category_list( $input ) {
  if ( $input != '' ) { 
    $args = array(
            'type'      => 'post',
            'child_of'      => 0,
            'parent'        => '',
            'orderby'       => 'name',
            'order'         => 'ASC',
            'hide_empty'    => 0,
            'hierarchical'  => 0,
            'taxonomy'      => 'category',
          ); 
    
    $categories = ( get_categories( $args ) );

    $category_list  = array();
    
    foreach ( $categories as $category )
      $category_list  = array_merge( $category_list, array( $category->term_id ) );

    if ( count( array_intersect( $input, $category_list ) ) == count( $input ) ) {
        return $input;
      } 
      else {
        return '';
      }
    }
    else {
      return '';
    }
}


if( ! function_exists( 'magzimum_is_featured_post_content_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_post_content_active( $control ) {
    $featured_content_type = $control->manager->get_setting( 'theme_options[featured_content_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-post' == $featured_content_type );
  }
endif;


if( ! function_exists( 'magzimum_is_featured_category_content_active' ) ) :
  /**
  * Return true if featured category content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_category_content_active( $control ) {
    $featured_content_type = $control->manager->get_setting( 'theme_options[featured_content_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-category' == $featured_content_type );
  }
endif;


if( ! function_exists( 'magzimum_is_featured_page_content_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_page_content_active( $control ) {
    $featured_content_type = $control->manager->get_setting( 'theme_options[featured_content_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-page' == $featured_content_type );
  }
endif;

if( ! function_exists( 'magzimum_is_featured_image_content_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_image_content_active( $control ) {
    $featured_content_type = $control->manager->get_setting( 'theme_options[featured_content_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-image' == $featured_content_type );
  }
endif;