<?php

add_filter( 'magzimum_filter_default_theme_options', 'magzimum_featured_story_default_options' );

/**
 * Featured story defaults.
 *
 * @since  Magzimum Pro 1.5
 */
if( ! function_exists( 'magzimum_featured_story_default_options' ) ):

  function magzimum_featured_story_default_options( $input ){

    $input['featured_story_enable']           = 'disabled';
    $input['featured_story_title']            = esc_html__( 'Featured Story', 'magzimum' );
    $input['num_of_featured_story']           = 4;
    $input['featured_story_type']         	  = 'featured-category';
    $input['featured_story_content_category'] = '';
    return $input;
  }

endif;



add_filter( 'magzimum_theme_options_args', 'magzimum_featured_story_theme_options_args' );


/**
 * Add Featured story options.
 *
 * @since  Magzimum Pro 1.5
 */

if( ! function_exists( 'magzimum_featured_story_theme_options_args' ) ):

  	function magzimum_featured_story_theme_options_args( $args ){

    // Create Featured story option panel
    $args['panels']['featured_story_panel']['title'] = esc_html__( 'Featured Story', 'magzimum' );
	
	$args['panels']['featured_story_panel']['sections']['section_featured_story_type'] = array(
	      'title'    => esc_html__( 'Featured story Type', 'magzimum' ),
	      'priority' => 70,
	      'fields'   => array(
	        'featured_story_enable' => array(
	          'title'   => esc_html__( 'Enable story on', 'magzimum' ),
	          'type'    => 'select',
	          'choices' => magzimum_get_featured_status_options(),
	          'priority'=>  1,
	        ),
	        'featured_story_type' => array(
	          'title'             => esc_html__( 'Select Featured story Type', 'magzimum' ),
	          'type'              => 'select',
	          'choices'           => magzimum_get_featured_story_type(),
	          'sanitize_callback' => 'sanitize_key',
	          'priority'          =>  2,
	        ),
	        'featured_story_title' => array(
	          'title' => esc_html__( 'Title', 'magzimum' ),
	          'type'  => 'text',
	          'priority'          =>  3,
	        ),
	        'num_of_featured_story' => array(
	          'title'             => esc_html__( 'Number of Posts', 'magzimum' ),
	          'type'              => 'number',
	          'sanitize_callback' => 'absint',
	          'priority'          =>  4,
	          'input_attrs'       => array(
	                                'min'   => 4,
	                                'max'   => 8,
	                                'step'  => 1,
	                                'style' => 'width: 50px;'
	                                ),
	        ),
		)
	);

    return $args;
  }

endif;

add_action( 'customize_register', 'magzimum_featured_story_loop_options' );
/**
 * Add featured story post, category loop
 *
 * @since  Magzimum Pro 1.5
 */

if( ! function_exists( 'magzimum_featured_story_loop_options' ) ):

  	function magzimum_featured_story_loop_options( $wp_customize ){


  		// Add featured story category setting and control.
		$wp_customize->add_setting(  'theme_options[featured_story_content_category]', array(
			'sanitize_callback' => 'absint',
		) ) ;

		$wp_customize->add_control( new Magzimum_Customize_Dropdown_Taxonomies_Control ( $wp_customize,'theme_options[featured_story_content_category]', array(
			'active_callback'	=> 'magzimum_is_featured_story_content_category',
			'label'             => esc_html__( 'Dropdown Category Control', 'magzimum' ),
			'section'           => 'section_featured_story_type',
			'type'              => 'dropdown-taxonomies',
		) ) );

	    $num_of_featured_story   = magzimum_get_option( 'num_of_featured_story' );

	    for ( $i=1; $i <= $num_of_featured_story; $i++ ) {
	      //Featured Post
	      	$wp_customize->add_setting( 'theme_options[featured_story_post_'. $i .']', array(
	          'capability'        => 'edit_theme_options',
	          'sanitize_callback' => 'absint', 
	        ) 
	      	);

	      	$wp_customize->add_control( 'theme_options[featured_story_post_'. $i .']', array(
	        'active_callback'   => 'magzimum_is_featured_story_post_slider_active',
	        'input_attrs'         => array(
	            'style' => 'width: 100px;'
	          ),
	        'label'             => esc_html__( 'Featured Post ID', 'magzimum' ) . ' ' . $i ,
	        'priority'          =>  '4' . $i,
	        'section'           => 'section_featured_story_type',
	        'settings'          => 'theme_options[featured_story_post_'. $i .']',
	        'type'              => 'text',
	        )
	      	);
    	}
	}
endif;


if( ! function_exists( 'magzimum_is_featured_story_post_slider_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum Pro 1.5
  */
  function magzimum_is_featured_story_post_slider_active( $control ) {
    $featured_story_type = $control->manager->get_setting( 'theme_options[featured_story_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-post' == $featured_story_type );
  }
endif;


if( ! function_exists( 'magzimum_is_featured_story_content_category' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum Pro 1.5
  */
  function magzimum_is_featured_story_content_category( $control ) {
    $featured_story_type = $control->manager->get_setting( 'theme_options[featured_story_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-category' == $featured_story_type );
  }
endif;