<?php

add_filter( 'magzimum_filter_default_theme_options', 'magzimum_slider_default_options' );

/**
 * Slider defaults.
 *
 * @since  Magzimum 1.0
 */
if( ! function_exists( 'magzimum_slider_default_options' ) ):

  function magzimum_slider_default_options( $input ){

    $input['featured_slider_status']                 = 'disabled';
    $input['featured_slider_transition_effect']      = 'fadeout';
    $input['featured_slider_transition_delay']       = 3;
    $input['featured_slider_transition_duration']    = 1;
    $input['featured_slider_full_width']             = true;
    $input['featured_slider_enable_caption']         = true;
    $input['featured_slider_enable_arrow']           = false;
    $input['featured_slider_enable_pager']           = true;
    $input['featured_slider_enable_autoplay']        = true;
    $input['featured_slider_enable_clickable_image'] = false;
    $input['featured_slider_type']                   = 'featured-category';
    $input['featured_slider_number']                 = 3;
    $input['featured_slider_category']               = array();

    return $input;
  }

endif;



add_filter( 'magzimum_theme_options_args', 'magzimum_slider_theme_options_args' );


/**
 * Add featured slider options.
 *
 * @since  Magzimum 1.0
 */

if( ! function_exists( 'magzimum_slider_theme_options_args' ) ):

  function magzimum_slider_theme_options_args( $args ){

    // Create featured slider option panel
    $args['panels']['featured_slider_panel']['title'] = esc_html__( 'Featured Slider', 'magzimum' );

    // Settings Section
    $args['panels']['featured_slider_panel']['sections']['section_slider_settings'] = array(
      'title'    => esc_html__( 'Slider Settings', 'magzimum' ),
      'priority' => 75,
      'fields'   => array(
        'featured_slider_transition_effect' => array(
          'title'   => esc_html__( 'Transition Effect', 'magzimum' ),
          'type'    => 'select',
          'choices' => magzimum_get_featured_slider_transition_effects(),
        ),

        'featured_slider_transition_delay' => array(
          'title'             => esc_html__( 'Transition Delay', 'magzimum' ),
          'description'       => esc_html__( 'In second(s)', 'magzimum' ),
          'type'              => 'number',
          'sanitize_callback' => 'absint',
          'input_attrs'       => array(
                                'min'   => 1,
                                'max'   => 10,
                                'step'  => 1,
                                'style' => 'width: 50px;'
                                ),

        ),
        'featured_slider_transition_duration' => array(
          'title'             => esc_html__( 'Transition Duration', 'magzimum' ),
          'description'       => esc_html__( 'In second(s)', 'magzimum' ),
          'type'              => 'number',
          'sanitize_callback' => 'absint',
          'input_attrs'       => array(
                                'min'   => 1,
                                'max'   => 10,
                                'step'  => 1,
                                'style' => 'width: 50px;'
                                ),
        ),
         'featured_slider_full_width' => array(
          'title'             => esc_html__( 'Enable Full Width Featured Slider', 'magzimum' ),
          'description'       => esc_html__( 'Checking this option will make Featured Slider  Full Width and Disable Sidebar Slider Right', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_slider_enable_caption' => array(
          'title'             => esc_html__( 'Enable Caption', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_slider_enable_arrow' => array(
          'title'             => esc_html__( 'Enable Arrow', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_slider_enable_pager' => array(
          'title'             => esc_html__( 'Enable Pager', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_slider_enable_autoplay' => array(
          'title'             => esc_html__( 'Enable Autoplay', 'magzimum' ),
          'type'              => 'checkbox',
        ),
        'featured_slider_enable_clickable_image' => array(
          'title'             => esc_html__( 'Enable Link in Image', 'magzimum' ),
          'type'              => 'checkbox',
        ),

      )
    );

    // Icons Section
    $args['panels']['featured_slider_panel']['sections']['section_slider_type'] = array(
      'title'    => esc_html__( 'Slider Type', 'magzimum' ),
      'priority' => 70,
      'fields'   => array(
        'featured_slider_status' => array(
          'title'   => esc_html__( 'Enable Slider on', 'magzimum' ),
          'type'    => 'select',
          'choices' => magzimum_get_featured_status_options(),
          'priority'=>  1,
        ),
        'featured_slider_type' => array(
          'title'             => esc_html__( 'Select Slider Type', 'magzimum' ),
          'type'              => 'select',
          'choices'           => magzimum_get_featured_slider_type(),
          'sanitize_callback' => 'sanitize_key',
          'priority'          =>  2,
        ),
        'featured_slider_number' => array(
          'title'             => esc_html__( 'No of Slides', 'magzimum' ),
          'type'              => 'number',
          'default'           => 3,
          'sanitize_callback' => 'absint',
          'input_attrs'       => array(
                                  'min'   => 1,
                                  'max'   => 20,
                                  'style' => 'width: 55px;'
                                ),
          'priority'          =>  3,

        ),
      )
    );

    return $args;
  }

endif;


add_action( 'customize_register', 'magzimum_featured_slider_loop_options' );

/**
 * Add featured slider post, page and image loop
 *
 * @since  Magzimum 1.0
 */

if( ! function_exists( 'magzimum_featured_slider_loop_options' ) ):

  function magzimum_featured_slider_loop_options( $wp_customize ){
    $wp_customize->add_setting( 'theme_options[featured_slider_category]', array(
          'capability'        => 'edit_theme_options',
          'sanitize_callback' => 'magzimum_sanitize_category_list',
        ) 
      );

    $wp_customize->add_control( new Magzimum_Customize_Dropdown_Multiple_Taxonomies_Control( $wp_customize, 'theme_options[featured_slider_category]', array(
        'name'              => 'theme_options[featured_slider_category]',
        'label'             => esc_html__( 'Select Categories', 'magzimum' ),
        'priority'          =>  7,
        'section'           => 'section_slider_type',
        'settings'          => 'theme_options[featured_slider_category]',
        'type'              => 'multiple-categories',
        'active_callback'   => 'magzimum_is_featured_category_slider_active'
    ) ) );

    $featured_slider_number   = magzimum_get_option( 'featured_slider_number' );

    for ( $i=1; $i <=  $featured_slider_number ; $i++ ) {
      //Featured Post
      $wp_customize->add_setting( 'theme_options[featured_slider_post_'. $i .']', array(
          'capability'        => 'edit_theme_options',
          'sanitize_callback' => 'absint', 
        ) 
      );

      $wp_customize->add_control( 'theme_options[featured_slider_post_'. $i .']', array(
        'input_attrs'         => array(
            'style' => 'width: 40px;'
          ),
        'label'             => esc_html__( 'Featured Post ID', 'magzimum' ) . ' ' . $i ,
        'priority'          =>  '4' . $i,
        'section'           => 'section_slider_type',
        'settings'          => 'theme_options[featured_slider_post_'. $i .']',
        'type'              => 'text',
        'active_callback'   => 'magzimum_is_featured_post_slider_active'
        )
      );

      //Featured Page
      $wp_customize->add_setting( 'theme_options[featured_slider_page_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'absint',
        ) 
      );

      $wp_customize->add_control( 'theme_options[featured_slider_page_'. $i .']', array(
        'label'     => esc_html__( 'Featured Page', 'magzimum' ) . ' ' . $i ,
        'priority'  => '5' . $i,
        'section'   => 'section_slider_type',
        'settings'  => 'theme_options[featured_slider_page_'. $i .']',
        'type'      => 'dropdown-pages',
        'active_callback'   => 'magzimum_is_featured_page_slider_active'
        ) 
      );
    
      //Featured Image
      $wp_customize->add_setting( 'theme_options[featured_slider_note_'. $i .']', array(
        'capability'    => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
      ) );

      $wp_customize->add_control( new Magzimum_Customize_Heading_Control( $wp_customize, 'theme_options[featured_slider_note_'. $i .']', array(
            'label'     => esc_html__( 'Featured Slide #', 'magzimum' ) .  $i,
            'priority'  => '6' . $i,
            'section'   => 'section_slider_type',
            'settings'  => 'theme_options[featured_slider_note_'. $i .']',
            'type'      => 'heading',
            'active_callback'   => 'magzimum_is_featured_image_slider_active'
        ) ) );

      $wp_customize->add_setting( 'theme_options[featured_slider_title_'. $i .']', array(
        'capability'    => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
      ) );

      $wp_customize->add_control( 'theme_options[featured_slider_title_'. $i .']', array(
        'label'     => esc_html__( 'Title', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_slider_type',
        'settings'  => 'theme_options[featured_slider_title_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_slider_active',
        'type'      => 'text',
        ) );

      $wp_customize->add_setting( 'theme_options[featured_slider_image_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
      ) );

      $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'theme_options[featured_slider_image_'. $i .']', array(
        'label'     => esc_html__( 'Image', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_slider_type',
        'settings'  => 'theme_options[featured_slider_image_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_slider_active'
      ) ) );

      $wp_customize->add_setting( 'theme_options[featured_slider_link_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
      ) );

      $wp_customize->add_control(  'theme_options[featured_slider_link_'. $i .']', array(
        'label'     => esc_html__( 'Link', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_slider_type',
        'settings'  => 'theme_options[featured_slider_link_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_slider_active',
      ) );

      $wp_customize->add_setting( 'theme_options[featured_slider_target_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_key',
      ) );

      $wp_customize->add_control(  'theme_options[featured_slider_target_'. $i .']', array(
        'label'     => esc_html__( 'Check to Open Link in New Window/Tab', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_slider_type',
        'settings'  => 'theme_options[featured_slider_target_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_slider_active',
        'type'      => 'checkbox',
      ) );

      $wp_customize->add_setting( 'theme_options[featured_slider_content_'. $i .']', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'wp_kses_post',
      ) );

      $wp_customize->add_control( 'theme_options[featured_slider_content_'. $i .']', array(
        'label'     => esc_html__( 'Content', 'magzimum' ),
        'priority'  => '6' . $i,
        'section'   => 'section_slider_type',
        'settings'  => 'theme_options[featured_slider_content_'. $i .']',
        'active_callback'   => 'magzimum_is_featured_image_slider_active',
        'type'      => 'textarea',
        )  );
    }
  }

endif;


if( ! function_exists( 'magzimum_is_featured_post_slider_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_post_slider_active( $control ) {
    $featured_slider_type = $control->manager->get_setting( 'theme_options[featured_slider_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-post' == $featured_slider_type );
  }
endif;


if( ! function_exists( 'magzimum_is_featured_category_slider_active' ) ) :
  /**
  * Return true if featured category content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_category_slider_active( $control ) {
    $featured_slider_type = $control->manager->get_setting( 'theme_options[featured_slider_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-category' == $featured_slider_type );
  }
endif;


if( ! function_exists( 'magzimum_is_featured_page_slider_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_page_slider_active( $control ) {
    $featured_slider_type = $control->manager->get_setting( 'theme_options[featured_slider_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-page' == $featured_slider_type );
  }
endif;

if( ! function_exists( 'magzimum_is_featured_image_slider_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum 1.0
  */
  function magzimum_is_featured_image_slider_active( $control ) {
    $featured_slider_type = $control->manager->get_setting( 'theme_options[featured_slider_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-image' == $featured_slider_type );
  }
endif;