<?php

if( ! function_exists( 'magzimum_get_header_image_enable_options' ) ) :

  /**
   * Returns header image enable options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_header_image_enable_options(){

    $choices = array(
      'homepage'              => esc_html__( 'Homepage / Frontpage', 'magzimum' ),
      'exclude-homepage'      => esc_html__( 'Excluding Homepage', 'magzimum' ),
      'exclude-home-page-post'=> esc_html__( 'Excluding Homepage, Page/Post Featured Image', 'magzimum' ), 
      'entire-site'           => esc_html__( 'Entire Site', 'magzimum' ),
      'entire-site-page-post' => esc_html__( 'Entire Site, Page/Post Featured Image', 'magzimum' ),
      'pages-posts'           => esc_html__( 'Pages and Posts', 'magzimum' ),
      'disable'               => esc_html__( 'Disabled', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_get_header_image_enable_options', $choices );

    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

  }

endif;

if( ! function_exists( 'magzimum_get_color_options' ) ) :

  /**
   * Returns color select options.
   *
   * @since Magzimum 1.5
   */
  function magzimum_get_color_options(){

    $choices = array(
      'default'               => esc_html__( 'Default', 'magzimum' ),
      'red'                   => esc_html__( 'Red', 'magzimum' ),
      'blue'                  => esc_html__( 'Blue', 'magzimum' ),
      'dark-green'            => esc_html__( 'Dark-Green','magzimum' ),
    );
    $output = apply_filters( 'magzimum_get_color_options', $choices );

    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

  }

endif;

if( ! function_exists( 'magzimum_get_custom_background_options' ) ) :

  /**
   * Returns background image enable options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_custom_background_options(){

    $choices = array(
      'entire-site'           => esc_html__( 'Entire Site', 'magzimum' ),
      'entire-site-page-post' => esc_html__( 'Entire Site, Page/Post Featured Image', 'magzimum' ),
      'disable'               => esc_html__( 'Disabled', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_get_custom_background_options', $choices );

    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

  }

endif;


if ( ! function_exists( 'magzimum_the_category_uno' ) ) :

  /**
   * Return one category link of a post.
   *
   * @since Magzimum 1.0
   */
  function magzimum_the_category_uno( $id = '' ){

    $output = magzimum_get_the_category_uno( $id );
    echo $output;

  }

endif;


if ( ! function_exists( 'magzimum_get_the_category_uno' ) ) :

  /**
   * Return one category link of a post.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_the_category_uno( $id = '' ){

    global $post;
    if ( empty( $id )) {
      if ( $post ) {
        $id = $post->ID;
      }
    }
    if ( empty( $id ) ) {
      return;
    }
    $categories = get_the_terms( $id, 'category' );
    if ( ! $categories || is_wp_error( $categories ) )
      $categories = array();

    $categories = array_values( $categories );
    $output = '';
    if ( ! empty( $categories ) && is_array( $categories ) ) {
      $cat = $categories[0];
      $output .= '<a href="' . esc_url( get_term_link( $cat ) ). '">' . esc_html( $cat->name ) . '</a>';
    }
    return $output;

  }

endif;


if( ! function_exists( 'magzimum_get_featured_slider_transition_effects' ) ) :

  /**
   * Returns the featured slider transition effects.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_featured_slider_transition_effects(){

    $choices = array(
      'fade'       => esc_html__( 'fade', 'magzimum' ),
      'fadeout'    => esc_html__( 'fadeout', 'magzimum' ),
      'none'       => esc_html__( 'none', 'magzimum' ),
      'scrollHorz' => esc_html__( 'scrollHorz', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_featured_slider_transition_effects', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

  }

endif;


if( ! function_exists( 'magzimum_get_featured_slider_content_options' ) ) :

  /**
   * Returns the featured slider content options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_featured_slider_content_options(){

    $choices = array(
      'home-page'   => esc_html__( 'Home Page / Front Page', 'magzimum' ),
      'entire-site' => esc_html__( 'Entire Site', 'magzimum' ),
      'disabled'    => esc_html__( 'Disabled', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_featured_slider_content_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;


  }

endif;


if( ! function_exists( 'magzimum_get_featured_slider_type' ) ) :

  /**
   * Returns the featured slider type.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_featured_slider_type(){

    $choices = array(
      'featured-post'     => esc_html__( 'Featured Post', 'magzimum' ),
      'featured-page'     => esc_html__( 'Featured Page', 'magzimum' ),
      'featured-category' => esc_html__( 'Featured Category', 'magzimum' ),
      'featured-image'    => esc_html__( 'Featured Image', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_featured_slider_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;


  }

endif;


if( ! function_exists( 'magzimum_get_featured_story_type' ) ) :

  /**
   * Returns the featured story type.
   *
   * @since Magzimum 1.5
   */
  function magzimum_get_featured_story_type(){

    $choices = array(
      'featured-post'     => esc_html__( 'Featured Post', 'magzimum' ),
      'featured-category' => esc_html__( 'Featured Category', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_featured_story_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;
  }
endif;

if( ! function_exists( 'magzimum_get_category_block_one_type' ) ) :

  /**
   * Returns the featured story type.
   *
   * @since Magzimum 1.5
   */
  function magzimum_get_category_block_one_type(){

    $choices = array(
      'featured-post'     => esc_html__( 'Featured Post', 'magzimum' ),
      'featured-category' => esc_html__( 'Featured Category', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_category_block_one_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;
  }
endif;

if( ! function_exists( 'magzimum_get_global_layout_options' ) ) :

  /**
   * Returns global layout options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_global_layout_options(){

    $choices = array(
      'left-sidebar'  => esc_html__( 'Primary Sidebar - Content', 'magzimum' ),
      'right-sidebar' => esc_html__( 'Content - Primary Sidebar', 'magzimum' ),
      'three-columns' => esc_html__( 'Three Columns', 'magzimum' ),
      'no-sidebar'    => esc_html__( 'No Sidebar', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_layout_options', $choices );
    return $output;

  }

endif;


if( ! function_exists( 'magzimum_get_site_layout_options' ) ) :

  /**
   * Returns site options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_site_layout_options(){

    $choices = array(
      'fluid' => esc_html__( 'Fluid', 'magzimum' ),
      'boxed' => esc_html__( 'Boxed', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_site_layout_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

  }

endif;


if( ! function_exists( 'magzimum_get_archive_layout_options' ) ) :

  /**
   * Returns archive layout options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_archive_layout_options(){

    $choices = array(
      'full'          => esc_html__( 'Full Post', 'magzimum' ),
      'excerpt'       => esc_html__( 'Excerpt Only', 'magzimum' ),
      'excerpt-thumb' => esc_html__( 'Excerpt and Thumbnail', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_archive_layout_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;


  }

endif;


if( ! function_exists( 'magzimum_get_image_sizes_options' ) ) :

  /**
   * Returns archive layout options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_image_sizes_options( $add_disable = true ){

    global $_wp_additional_image_sizes;
    $get_intermediate_image_sizes = get_intermediate_image_sizes();
    $choices = array();
    if ( true == $add_disable ) {
      $choices['disable'] = esc_html__( 'No Image', 'magzimum' );
    }
    foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
      $choices[ $_size ] = $_size . ' ('. get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
    }
    $choices['full'] = esc_html__( 'full (original)', 'magzimum' );
    if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {

      foreach ($_wp_additional_image_sizes as $key => $size ) {
        $choices[ $key ] = $key . ' ('. $size['width'] . 'x' . $size['height'] . ')';
      }

    }
    return $choices;

  }

endif;



if( ! function_exists( 'magzimum_get_single_image_alignment_options' ) ) :

  /**
   * Returns single image options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_single_image_alignment_options(){

    $choices = array(
      'none'   => esc_html__( 'None', 'magzimum' ),
      'left'   => esc_html__( 'Left', 'magzimum' ),
      'center' => esc_html__( 'Center', 'magzimum' ),
      'right'  => esc_html__( 'Right', 'magzimum' ),
    );
    return $choices;

  }

endif;


if( ! function_exists( 'magzimum_get_optional_sidebar_options' ) ) :

  /**
   * Returns optional sidebar options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_optional_sidebar_options(){
    $choices = array(
      'optional-sidebar-one'  => esc_html__( 'Optional Sidebar One', 'magzimum' ),
      'optional-sidebar-two'  => esc_html__( 'Optional Sidebar Two', 'magzimum' ),
      'optional-sidebar-three'=> esc_html__( 'Optional Sidebar Three', 'magzimum' ),
    );
    return $choices;

  }

endif;


if( ! function_exists( 'magzimum_get_pagination_type_options' ) ) :

  /**
   * Returns pagination type options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_pagination_type_options(){

    $choices = array(
      'default' => esc_html__( 'Default (Older Post / Newer Post)', 'magzimum' ),
      'numeric' => esc_html__( 'Numeric', 'magzimum' ),
      'infinite'=> esc_html__( 'Infinite Scroll', 'magzimum' )
    );
    return $choices;

  }

endif;


if( ! function_exists( 'magzimum_get_breadcrumb_type_options' ) ) :

  /**
   * Returns breadcrumb type options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_breadcrumb_type_options(){

    $choices = array(
      'disabled' => esc_html__( 'Disabled', 'magzimum' ),
      'simple'   => esc_html__( 'Simple', 'magzimum' ),
      'advanced' => esc_html__( 'Advanced', 'magzimum' ),
    );
    return $choices;

  }

endif;


if( ! function_exists( 'magzimum_get_featured_status_options' ) ) :

  /**
   * Returns featured status options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_featured_status_options(){

    $choices = array(
      'home-page-only' => esc_html__( 'Home Page Only', 'magzimum' ),
      'home-blog-page' => esc_html__( 'Home Page + Blog Page', 'magzimum' ),
      'entire-site'    => esc_html__( 'Entire Site', 'magzimum' ),
      'disabled'       => esc_html__( 'Disabled', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_featured_status_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

  }

endif;


if( ! function_exists( 'magzimum_get_featured_content_type_options' ) ) :

  /**
   * Returns the featured content type options.
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_featured_content_type_options(){

    $choices = array(
      'featured-post'     => esc_html__( 'Featured Post', 'magzimum' ),
      'featured-page'     => esc_html__( 'Featured Page', 'magzimum' ),
      'featured-category' => esc_html__( 'Featured Category', 'magzimum' ),
      'featured-image'    => esc_html__( 'Featured Image', 'magzimum' ),
    );
    $output = apply_filters( 'magzimum_filter_featured_content_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;


  }

endif;

if( ! function_exists( 'magzimum_get_avaliable_fonts' ) ) :

  /**
   * Returns available fonts
   *
   * @since Magzimum 1.0
   */
  function magzimum_get_avaliable_fonts(){

    $choices = array(
    'arial-black'         => esc_html__( '"Arial Black", Gadget, sans-serif','magzimum' ),
    'allan'               => esc_html__( '"Allan", sans-serif','magzimum' ),
    'allerta'             => esc_html__( '"Allerta", sans-serif','magzimum' ),
    'amaranth'            => esc_html__( '"Amaranth", sans-serif','magzimum' ),
    'arial'               => esc_html__( 'Arial, Helvetica, sans-serif','magzimum' ),
    'arvo'                => esc_html__( '"Arvo", sans-serif','magzimum' ),
    'bitter'              => esc_html__( '"Bitter", sans-serif','magzimum' ),
    'balthazar'           => esc_html__( '"Balthazar", sans-serif','magzimum' ),
    'cabin'               => esc_html__( '"Cabin", sans-serif','magzimum' ),
    'cantarell'           => esc_html__( '"Cantarell", sans-serif','magzimum' ),
    'century-gothic'      => esc_html__( '"Century Gothic", sans-serif','magzimum' ),
    'courier-new'         => esc_html__( '"Courier New", Courier, monospace','magzimum' ),
    'crimson-text'        => esc_html__( '"Crimson Text", sans-serif','magzimum' ),
    'cuprum'              => esc_html__( '"Cuprum", sans-serif','magzimum' ),
    'dancing-script'      => esc_html__( '"Dancing Script", sans-serif','magzimum' ),
    'droid-sans'          => esc_html__( '"Droid Sans", sans-serif','magzimum' ),
    'droid-serif'         => esc_html__( '"Droid Serif", sans-serif','magzimum' ),
    'exo'                 => esc_html__( '"Exo", sans-serif','magzimum' ),
    'exo-2'               => esc_html__( '"Exo 2", sans-serif','magzimum' ),
    'georgia'             => esc_html__( 'Georgia, "Times New Roman", Times, serif','magzimum' ),
    'helvetica'           => esc_html__( 'Helvetica, "Helvetica Neue", Arial, sans-serif','magzimum' ),
    'helvetica-neue'      => esc_html__( '"Helvetica Neue",Helvetica,Arial,sans-serif','magzimum' ),
    'istok-web'           => esc_html__( '"Istok Web", sans-serif','magzimum' ),
    'impact'              => esc_html__( 'Impact, Charcoal, sans-serif','magzimum' ),
    'lato'                => esc_html__( '"Lato", sans-serif','magzimum' ),
    'lucida-sans-unicode' => esc_html__( '"Lucida Sans Unicode", "Lucida Grande", sans-serif','magzimum' ),
    'lucida-grande'       => esc_html__( '"Lucida Grande", "Lucida Sans Unicode", sans-serif','magzimum' ),
    'lobster'             => esc_html__( '"Lobster", sans-serif','magzimum' ),
    'lora'                => esc_html__( '"Lora", serif','magzimum' ),
    'monaco'              => esc_html__( 'Monaco, Consolas, "Lucida Console",monospace, sans-serif','magzimum' ),
    'montserrat'          => esc_html__( '"Montserrat", sans-serif','magzimum' ),
    'nobile'              => esc_html__( '"Nobile", sans-serif','magzimum' ),
    'noto-serif'          => esc_html__( '"Noto Serif", serif','magzimum' ),
    'neuton'              => esc_html__( '"Neuton", serif','magzimum' ),
    'open-sans'           => esc_html__( '"Open Sans", sans-serif','magzimum' ),
    'oswald'              => esc_html__( '"Oswald", sans-serif','magzimum' ),
    'palatino'            => esc_html__( 'Palatino, "Palatino Linotype", "Book Antiqua", serif','magzimum' ),
    'patua-one'           => esc_html__( '"Patua One", sans-serif','magzimum' ),
    'playfair-display'    => esc_html__( '"Playfair Display", sans-serif','magzimum' ),
    'pt-sans'             => esc_html__( '"PT Sans", sans-serif','magzimum' ),
    'pt-serif'            => esc_html__( '"PT Serif", serif','magzimum' ),
    'quattrocento-sans'   => esc_html__( '"Quattrocento Sans", sans-serif','magzimum' ),
    'roboto'              => esc_html__( '"Roboto", sans-serif','magzimum' ),
    'roboto-slab'         => esc_html__( '"Roboto Slab", serif','magzimum' ),
    'sans-serif'          => esc_html__( 'Sans Serif, Arial','magzimum' ),
    'source-sans-pro'     => esc_html__( '"Source Sans Pro", sans-serif','magzimum' ),
    'tahoma'              => esc_html__( 'Tahoma, Geneva, sans-serif','magzimum' ),
    'trebuchet-ms'        => esc_html__( '"Trebuchet MS", "Helvetica", sans-serif','magzimum' ),
    'times-new-roman'     => esc_html__( '"Times New Roman", Times, serif','magzimum' ),
    'ubuntu'              => esc_html__( '"Ubuntu", sans-serif','magzimum' ),
    'verdana'             => esc_html__( 'Verdana, Geneva, sans-serif','magzimum' ),
    'yanone-kaffeesatz'   => esc_html__( '"Yanone Kaffeesatz", sans-serif','magzimum' ),
  );

  $output = apply_filters( 'magzimum_filter_avaliable_fonts', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

  }

endif;

if( ! function_exists( 'magzimum_sanitize_checkbox' ) ) :
  /**
   * Sanitize checkbox.
   *
   * @since 1.5
   *
   * @param bool $checked Whether the checkbox is checked.
   * @return bool Whether the checkbox is checked.
   */
  function magzimum_sanitize_checkbox( $checked ) {
    // Boolean check.
    return ( isset( $checked ) && true == $checked ) ? true : false ;
  }
endif;