<?php
/**
 * Feature story section
 *
 * This is the template for the content of Featured Story section.
 *
 * @package Theme Palace
 * @subpackage Magzimum Pro
 * @since Magzimum Pro 1.5
 */

// Check status
add_filter( 'magzimum_filter_featured_story_status', 'magzimum_check_featured_story_status' );

if ( ! function_exists( 'magzimum_add_featured_story_section' ) ) :
    /**
     * Add Feature story section
     *
     * @since 1.5
     */
    function magzimum_add_featured_story_section() {

        // Check if Feature story is enabled on
        $featured_story_enable = apply_filters( 'magzimum_filter_featured_story_status', true, 'featured_story_enable' );
        if ( true !== $featured_story_enable ) {
            return false;
        }
        // Get Feature story section details
        $section_details = array();
        $section_details = apply_filters( 'magzimum_filter_featured_story_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
       
        // Render Feature story section .
        magzimum_render_featured_story_section( $section_details );
    }
endif;
add_action( 'magzimum_action_before_content', 'magzimum_add_featured_story_section', 6 );


if ( ! function_exists( 'magzimum_get_featured_story_section_details' ) ) :
    /**
     * Feature story section details.
     *
     * @since 1.5
     *
     * @param array $input Feature story section details.
     */
    function magzimum_get_featured_story_section_details( $input ) {

        $content = array();
        $no_of_post = magzimum_get_option( 'num_of_featured_story' );

        switch ( magzimum_get_option('featured_story_type' ) ) {
            
            case 'featured-category':
                $category = '';
                $featured_story_content_category = magzimum_get_option('featured_story_content_category' );
                if ( ! empty( $featured_story_content_category ) ) {
                    $category = $featured_story_content_category;
                }

                if ( ! empty( $category ) ) {
                
                    $args = array(
                        'cat'               => $category,
                        'posts_per_page'    => $no_of_post
                    );
                }
            break;

            case 'featured-post':
                $post_list = array();
                for ( $i = 1; $i <= $no_of_post ; $i++ ) { 
                    $featured_story_post = magzimum_get_option('featured_story_post_' . $i );
                    $post_id    = ! empty ( $featured_story_post ) ? absint( $featured_story_post ) : '';
                    $post_list  = array_merge( $post_list, array( $post_id ) );
                }

                if ( ! empty( $post_list ) ) {
                
                    $args = array(
                        'post__in'           => $post_list,
                        'posts_per_page'    => $no_of_post,
                    );
                }
            break;

            default:
            break;          
        }
            
        if( ! empty ( $args ) ) :
            $custom_posts = get_posts( $args );

            $i = 0;
            foreach ( $custom_posts as $key => $custom_post ) {
                $img_array = null;

                if ( has_post_thumbnail( $custom_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'magzimum-featured' );
                } else {
                        $img_array = array ( get_template_directory_uri() . '/assets/images/no-featured-image-275x206.png' );
                }

                if ( isset( $img_array ) ) {
                    $content[$i]['img_array'] = $img_array;
                }

                $content[$i]['url']      = get_permalink( $custom_post->ID );
                $content[$i]['title']    = get_the_title( $custom_post->ID );
                $content[$i]['excerpt']  = magzimum_get_the_excerpt( 20, $custom_post );
                $content[$i]['date']     = get_the_date( '', $custom_post->ID );
            $i++;
            }
        endif;
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input;      
    }
endif;
// Feature story section content details.
add_filter( 'magzimum_filter_featured_story_section_details', 'magzimum_get_featured_story_section_details' );

if ( ! function_exists( 'magzimum_render_featured_story_section' ) ) :
    /**
     * Start section  feature-story
     *
     * @return string Feature story content
     * @since Magzimum Pro 1.5
     *
     */
    function magzimum_render_featured_story_section( $content_details = array() ) {
    
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <section id="featured-story" class="page-section no-padding-bottom">
            <?php $section_title = magzimum_get_option( 'featured_story_title' );
                
            if(! empty( $section_title ) ) : ?>
            <div class="bg-blue">
                <header class="container entry-header text-left">
                    <h2 class="entry-title padding-top-bottom color-white"><?php echo esc_html( $section_title ); ?></h2>
                </header>
            </div><!-- end .bg-blue -->
            <?php endif; ?>

                <div class="entry-content"> 
                    <div class="container"> 
                        
                        <?php
                            $carousel_visible_count = count($content_details);
                            if ( $carousel_visible_count >= 4 ) 
                                $carousel_visible_count = 4;
                            else 
                                $carousel_visible_count ;
                        ?>
                        <div class="cycle-slideshow" data-cycle-auto-height="calc" data-cycle-slides=">.featured-slider" data-cycle-fx="carousel" data-cycle-carousel-fluid="true" data-cycle-timeout="3000" data-cycle-speed="700" data-cycle-carousel-visible="<?php echo absint( $carousel_visible_count ); ?>" data-cycle-next=".cycle-next" data-cycle-prev=".cycle-prev">

                            <?php foreach( $content_details as $content ) : ?>
                            <div class="featured-slider">
                                <?php if( !empty ( $content['img_array'][0] ) ) : ?>
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                <?php endif; ?>
                                <div class="featured-contents">
                                    
                                    <?php if( !empty ( $content['title'] ) ) : ?>
                                        <div class="title">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><h3><?php echo esc_html( $content['title'] ); ?></h3></a>
                                        </div><!-- end .title -->
                                    <?php endif;  

                                    if( !empty ( $content['date'] ) ) : ?>
                                        <span class="date">
                                            <?php echo esc_html( $content['date'] ); ?>
                                        </span><!-- end .date -->
                                    <?php endif;
                                    
                                    if( !empty ( $content['excerpt'] ) ) : ?>
                                        <span class="description">
                                            <?php echo esc_html( $content['excerpt'] ); ?> 
                                        </span>
                                    <?php endif; ?>
                                </div><!-- end featured-contents -->
                            </div><!-- end .featured-slider -->
                            <?php endforeach; ?>
                        </div><!--end cycle-slideshow-->
                        <div class="controls">
                            <div class="cycle-prev"><a href="#"><i class="fa fa-angle-left"></i></a></div>
                            <div class="cycle-next"><a href="#"><i class="fa fa-angle-right"></i></a></div>
                        </div><!--end .controls-->
                    </div><!-- end .container -->
                </div><!-- end entry-content -->
        </section><!-- end .featured-story -->
<?php
    }
endif;




/**
 * Check status of featured story.
 *
 * @since Magzimum 1.5
 *
 */
if( ! function_exists( 'magzimum_check_featured_story_status' ) ):

  function magzimum_check_featured_story_status( $input ){

    // Featured status
    $featured_content_status = magzimum_get_option( 'featured_story_enable' );

    // Initial
    $status = false;

    switch ( $featured_content_status ) {

      case 'entire-site':
        $status = true;
        break;

      case 'home-page-only':
        if ( is_front_page() ) {
          $status = true;
        }
        break;

      case 'home-blog-page':
        if ( is_front_page() || is_home() ) {
          $status = true;
        }
        break;

      case 'disabled':
      default:
        $status = false;
        break;

    }

    return $status;

  }

endif;